@@ -5,17 +5,16 @@ f.HWE.design <- function(data, design, sex){
 ## STRUCTURE
 ##
 
-.alleles <- attr(data, "alleles")
-.nloci <- length(.alleles)
+nloci <- length( data$aux$alleles )
+data.gen <- data$gen.data
+# if(!is.numeric(data)) stop("Data format wrong when testing HWE!")
 
-if(!is.numeric(data)) stop("Data format wrong when testing HWE!")
-#
 ## ITERATE TESTING OVER LOCI
-.ut <- vector(.nloci, mode = "list")
-for(i in 1:.nloci){
+.ut <- vector( nloci, mode = "list" )
+for(i in 1:nloci){
 	## FOR EACH LOCUS, STACK MOTHER, FATHER, CHILD AND COMPUTE JOINTLY (IF TRIADS)
 	if(design %in% c("triad", "cc.triad")){
-		.data.tmp <- data[, ((i-1)*6 + 1):((i-1)*6 + 6)]
+		.data.tmp <- data.gen[, ((i-1)*6 + 1):((i-1)*6 + 6)]
 		if(missing(sex)){# AUTOSOME TRIAD
 			.data.tmp <- rbind(.data.tmp[,1:2], .data.tmp[,3:4], .data.tmp[,5:6])
 		}else{# TRIAD ON X-CHROM
@@ -23,7 +22,7 @@ for(i in 1:.nloci){
 		}
 	}
 	if(design == "cc"){
-		.data.tmp <- data[, ((i-1)*2 + 1):((i-1)*2 + 2)]
+		.data.tmp <- data.gen[, ((i-1)*2 + 1):((i-1)*2 + 2)]
 		if(!missing(sex)){
 			.data.tmp <- .data.tmp[sex == 2,] # USES ONLY GIRLS
 		}
