@@ -1,4 +1,4 @@
-haptable <- function(object, ...){
+haptable <- function(object){
 ## CREATES A SUMMARY TABLE OF ESTIMATION RESULTS FROM HAPLIN
 ## object IS THE RESULT FROM A HAPLIN RUN
 ##
